#
# spec file for package k6
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           k6
Version:        1.0.0
Release:        1.1
Summary:        Modern load testing tool, using Go and JavaScript
License:        AGPL-3.0
URL:            https://github.com/grafana/k6
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.23
BuildRequires:  zsh

# # github.com/grafana/xk6-output-prometheus-remote/pkg/remote
# vendor/github.com/grafana/xk6-output-prometheus-remote/pkg/remote/client.go:131:35: cannot use math.MaxUint32 (untyped int constant 4294967295) as int value in argument to fmt.Errorf (overflows)
# # github.com/grafana/xk6-dashboard/dashboard
# vendor/github.com/grafana/xk6-dashboard/dashboard/sse.go:69:31: cannot use maxSafeInteger (untyped int constant 9007199254740991) as int value in argument to strconv.Itoa (overflows)
# # go.k6.io/k6/output/cloud/expv2
# output/cloud/expv2/metrics_client.go:89:35: cannot use 0xffffffff (untyped int constant 4294967295) as int value in argument to fmt.Errorf (overflows)
ExcludeArch:    %{ix86}

%description
k6 is a modern load-testing tool, built on our years of experience in the
performance and testing industries. It's built to be powerful, extensible, and
full-featured. The key design goal is to provide the best developer experience.

Its core features are:

- Configurable load generation. Even lower-end machines can simulate lots of
  traffic.
- Tests as code. Reuse scripts, modularize logic, version control, and
  integrate tests with your CI.
- A full-featured API. The scripting API is packed with features that help you
  simulate real application traffic.
- An embedded JavaScript engine. The performance of Go, the scripting
  familiarity of JavaScript.
- Multiple Protocol support. HTTP, WebSockets, gRPC, Browser, and more.
- Large extension ecosystem. You can extend k6 to support your needs. And many
  people have already shared their extensions with the community!
- Flexible metrics storage and visualization. Summary statistics or granular
  metrics, exported to the service of your choice.
- Native integration with Grafana cloud. SaaS solution for test execution,
  metrics correlation, data analysis, and more.

This is what load testing looks like in the 21st century.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -o bin/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md examples
%license LICENSE.md
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Tue May  6 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.0.0:
  Grafana k6 v1.0 is here!
  After 9 years of iteration and countless community contributions,
  we're thrilled to announce Grafana k6 v1.0.
  While many features and capabilities in this release were
  introduced gradually in previous versions, k6 v1.0 marks a
  turning point: a commitment to stability, formal support
  guarantees, and transparency in how we evolve and develop the
  project from here. This milestone is more than a version number;
  it's about trust, reliability, and empowering you to test
  confidently.
  What's New in k6 1.0?
  * Stability You Can Build On
  * First-Class TypeScript Support
  * Extensions Made Simple
  * Revamped test summary
  * Quality of Life Upgrades
  Full changelog:
  https://github.com/grafana/k6/releases/tag/v1.0.0
* Tue May  6 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.59.0:
  The v0.59.0 release mirrors the previous v1.0.0-rc2 release to
  allow automation tools to recognize it as the latest version.
  For example, Homebrew's k6 formulae and pkg.go.dev do not
  automatically fetch unstable versions such as v1.0.0-rc2, which
  is legitimately the expected behavior for these tools.
  However, this has been the default for all previous v0.*
  releases, where they were considered the latest stable
  version—even if they were under a version typically associated
  with unstable releases. To address this, we will continue
  releasing mirrored versions under v0.* for necessary release
  candidates.
  This practice will end once the official stable v1.0.0 release is
  available, after which we will follow the standard SemVer
  lifecycle to simplify the workflow for everyone.
  The release notes for v1.0.0-rc2 provide a detailed look at all
  the changes that have been implemented since v1.0.0-rc1/v0.58.0
  and are now part of this version.
  * New features
  - Native support for extensions in the Cloud #4671
    The new Binary Provisioning feature automatically requests
    and uses custom k6 binaries with the required extensions for
    your tests. This allows you to run scripts that use
    extensions without manually rebuilding k6 as it was in the
    past by depending on tools like xk6. The system caches
    binaries locally for efficiency, and any additional runs with
    the same dependencies will use the same binary and will run
    faster.
    Binary Provisioning is available for all k6 Cloud users (free
    and paid plans). It is an experimental feature, it's enabled
    by opt-in with the feature flag K6_BINARY_PROVISIONING=true.
    Binary provisioning is a limited set of extensions that are
    supported, and it's not available for the k6 run command that
    might be added in the future. However, local development is
    supported with the k6 cloud --local-execution command if a
    cloud token is provided by the canonical login methods.
    Check out the documentation for additional details.
    https://grafana.com/docs/grafana-cloud/testing/k6/author-run/use-k6-extensions
  - Test failure control with execution.test.fail #4672
    The new execution.test.fail function allows you to explicitly
    fail a test while letting it continue execution until
    completion. This gives you more control over test outcomes
    while still collecting all metrics and completing necessary
    cleanup tasks.
  * UX improvements and enhancements
  - #4698 Displays threshold values even when are not configured
    in summaryTrendStats option.
  - #4699 Drops the link of the legacy k6 website from the user
    agent.
  * Bug fixes
  - #4717 Safeguards against pressedKeys being updated
    concurrently in the browser module.
  - #4665 Prevents race condition between Ended & Interrupted
    execution states.
  - #4677 Makes secretsource also redact float32 and float64
    values.
  * Maintenance and internal improvements
  - #4675, #4676, #4678 Move several packages to internal as
    preparations for v1.0.0 stabilization
  - #4686 Drops the redundant NO_COLOR detection.
  - #4709 Fixes JS native objects override to avoid a page under
    the test from overwriting native JavaScript objects, like Set
    and Map.
  - #4726 Unifies the internal/cmd.Execute methods.
  - #4703 Makes wptTests run without tags or skip if repos not
    checkout.
  - #4701 Fixes WebCrypto errors not propagating from the tests.
  - #4691, #4674, #4673, #4663 Bumps the versions for
    OpenTelemetry, grpc, golang/x and esbuild dependencies.
  - #4691 Bumps x509roots/fallback dependency for fallback
    certificates.
  - #4739 Removes deprecated GetLayoutMetrics.VisualViewport CDP
    usage.
* Mon Mar 31 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.58.0:
  The v0.58.0 release mirrors the previous v1.0.0-rc1 release to
  allow automation tools to recognize it as the latest version.
  For example, Homebrew's k6 formulae and pkg.go.dev do not
  automatically fetch unstable versions such as v1.0.0-rc1, which
  is legitimately the expected behavior for these tools.
  However, this has been the default for all previous v0.*
  releases, where they were considered the latest stable
  version—even if they were under a version typically associated
  with unstable releases. To address this, we will continue
  releasing mirrored versions under v0.* for necessary release
  candidates.
  This practice will end once the official stable v1.0.0 release is
  available, after which we will follow the standard SemVer
  lifecycle to simplify the workflow for everyone.
  The release notes for v1.0.0-rc1 provide a detailed look at all
  the changes that have been implemented since v0.57.0 and are now
  part of this version.
  https://github.com/grafana/k6/releases/v1.0.0-rc1
* Tue Mar 18 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.57.0:
  * Release v0.57.0 (#4511)
  * Bump k6 version
  * Add TODO to Frame.SetContent (#4538)
  * browser: race fix in page.setInputFiles
  * browser: race fix in page.SetViewportSize
  * browser: race fix in page.selectOptions and co
  * Drop not true TODO comments
  * browser: race fix in page.screenshot
  * browser: race fix in page/frame.Check
  * Fix setContent racy access to options
* Tue Mar 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package k6: a modern load testing tool, using Go and
  JavaScript
